@@ -146,14 +146,20 @@ def build_filter(model: Type[BaseModel], data: Dict[str, Any]) -> Dict[str, Any]
         if data.get(field) and data[field] != info.default:
             default = data[field]
         if info.annotation == Optional[List[str]]:  # type: ignore
+            mapping = groups_mapping().get(field)
+            if not mapping:
+                continue
             data[field] = st.multiselect(
                 name,
-                groups_mapping()[field],
+                mapping,
                 default=default,
                 key=hash((model.__name__, field)),
             )
         elif info.annotation == Optional[str]:  # type: ignore
-            options = ["", *groups_mapping()[field]]
+            mapping = groups_mapping().get(field)
+            if not mapping:
+                continue
+            options = ["", *mapping]
             data[field] = st.selectbox(
                 name,
                 options,
@@ -183,7 +189,7 @@ def build_filter(model: Type[BaseModel], data: Dict[str, Any]) -> Dict[str, Any]
             except Exception as e:
                 logger.error(
                     f"Error building filter for {model.__name__}.{field} "
-                    f"with the parameters {(info.annotation, name, ge, le, tuple(default))}: {e}"
+                    f"with the parameters {(info.annotation, name, ge, le)}: {e}"
                 )
                 raise e
     return data
